The Element trait, and various elements.
Structs
- Cursor
- An element that places the cursor at its position.
- Fixed
Width - An element that pads or truncates its contents to a constant width.
- Gap
- An element that renders a blank space of the specified width.
- Styled
- An element that renders its content with a particular style.
- Text
- An element that renders a piece of text.
Enums
- Direction
- The alignment or padding applied to a
FixedWidthelement.
Traits
- Element
- A particular widget that can be rendered to the TUI.
- Into
Element - A type that can be converted into an element.